import ec2 = require('@aws-cdk/aws-ec2');
import secretsmanager = require('@aws-cdk/aws-secretsmanager');
import { Construct } from '@aws-cdk/cdk';
/**
 * A secret rotation serverless application.
 */
export declare class SecretRotationApplication {
    static readonly MariaDbRotationSingleUser: SecretRotationApplication;
    static readonly MariaDBRotationMultiUser: SecretRotationApplication;
    static readonly MysqlRotationSingleUser: SecretRotationApplication;
    static readonly MysqlRotationMultiUser: SecretRotationApplication;
    static readonly OracleRotationSingleUser: SecretRotationApplication;
    static readonly OracleRotationMultiUser: SecretRotationApplication;
    static readonly PostgresRotationSingleUser: SecretRotationApplication;
    static readonly PostgreSQLRotationMultiUser: SecretRotationApplication;
    static readonly SqlServerRotationSingleUser: SecretRotationApplication;
    static readonly SqlServerRotationMultiUser: SecretRotationApplication;
    readonly applicationId: string;
    readonly semanticVersion: string;
    constructor(applicationId: string, semanticVersion: string);
}
/**
 * Options to add secret rotation to a database instance or cluster.
 */
export interface SecretRotationOptions {
    /**
     * Specifies the number of days after the previous rotation before
     * Secrets Manager triggers the next automatic rotation.
     *
     * @default 30 days
     */
    readonly automaticallyAfterDays?: number;
}
/**
 * Construction properties for a SecretRotation.
 */
export interface SecretRotationProps extends SecretRotationOptions {
    /**
     * The secret to rotate. It must be a JSON string with the following format:
     * {
     *   'engine': <required: database engine>,
     *   'host': <required: instance host name>,
     *   'username': <required: username>,
     *   'password': <required: password>,
     *   'dbname': <optional: database name>,
     *   'port': <optional: if not specified, default port will be used>,
     *   'masterarn': <required for multi user rotation: the arn of the master secret which will be used to create users/change passwords>
     * }
     *
     * This is typically the case for a secret referenced from an AWS::SecretsManager::SecretTargetAttachment
     * https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-secretsmanager-secrettargetattachment.html
     */
    readonly secret: secretsmanager.ISecret;
    /**
     * The serverless application for the rotation.
     */
    readonly application: SecretRotationApplication;
    /**
     * The VPC where the Lambda rotation function will run.
     */
    readonly vpc: ec2.IVpc;
    /**
     * The type of subnets in the VPC where the Lambda rotation function will run.
     *
     * @default - Private subnets.
     */
    readonly vpcSubnets?: ec2.SubnetSelection;
    /**
     * The target database cluster or instance
     */
    readonly target: ec2.IConnectable;
}
/**
 * Secret rotation for a database instance or cluster.
 */
export declare class SecretRotation extends Construct {
    constructor(scope: Construct, id: string, props: SecretRotationProps);
}
